@@ -19,7 +19,6 @@ return [
     'Account' => 'Rekening',
     'Active' => 'Aktief',
     'Active Configurations' => 'Aktiewe verbindings',
-    'Advanced' => 'Gevorderd',
     'Aggregated' => 'Saamgevoeg',
     'All' => 'Alle',
     'An application attempts to establish a VPN connection.' => '\'n program probeer om \'n VPN-verbinding te vestig.',
@@ -96,19 +95,21 @@ return [
     'Online' => 'Aanlyn',
     'Only approve this when you are trying to establish a VPN connection with this application!' => 'Keur hierdie goed slegs as U \'n VPN-verbinding met hierdie program probeer bevestig!',
     'OpenVPN' => 'OpenVPN',
+    //'OpenVPN (Prefer TCP)' => '',
+    //'OpenVPN (Prefer UDP)' => '',
     'OpenVPN Server Log' => 'OpenVPN bediener Log',
     'Password' => 'Wagwoord',
     'Permissions' => 'Toestemming',
     'Please sign in with your username and password.' => 'Meld aan met U gebruikersnaam en wagwoord.',
     'Port' => 'Poort',
     'Ports' => 'Poorte',
-    'Prefer connecting over TCP (OpenVPN)' => 'Verbinding oor TCP (OpenVPN) word verkies',
     'Preferred Protocol' => 'Voorkeur Protokol',
     'Profile' => 'Profiel',
-    'Profile Default' => 'Profiel verstek',
+    //'Profile ID' => '',
     'Profile Usage' => 'Profiel gebruik',
     'Profile(s)' => 'Profiel(e)',
     'Public Key' => 'Publieke Sleutel',
+    //'Refresh' => '',
     'Results' => 'Uitslae',
     'Revoke' => 'Herroep',
     'Route(s)' => 'Roete(s)',
@@ -133,7 +134,6 @@ return [
     'This user does not have any active configurations.' => 'Die gebruiker het nie aktiewe verstelling nie.',
     'This user does not have any connections.' => 'Die gebruiker het nie huidige verbindings nie.',
     'To prevent malicious applications from secretly establishing a VPN connection on your behalf, you have to explicitly approve this application first.' => 'U moet eers hierdie toepassing uitdruklik goedkeur om te verhoed dat kwaadwillige VPN-verbindings in die geheim namens jou gemaak word.',
-    'Use Protocol' => 'Gebruiksprotokol',
     'Use the WireGuard app on your mobile device to scan this QR code.' => 'Gebruik die WireGuard-program op U mobile toestel om hierdie QR kode te skandeer.',
     'User ID' => 'Gebruiker-ID',
     'Username' => 'Gebruikersnaam',
