@@ -19,7 +19,6 @@ return [
     'Account' => 'حساب',
     'Active' => 'نشط',
     'Active Configurations' => 'اعدادات نشطة',
-    'Advanced' => 'متقدم',
     'Aggregated' => 'مجمع',
     'All' => 'الكل',
     'An application attempts to establish a VPN connection.' => 'يحاول تطبيق الاتصال مع الشبكة الخاصة الافتراضية.',
@@ -96,19 +95,21 @@ return [
     'Online' => 'على الشبكة',
     'Only approve this when you are trying to establish a VPN connection with this application!' => 'وافق فقط عندما تحاول الاتصال بالشبكة الخاصة الافتراضية عبر هذا التطبيق!',
     'OpenVPN' => 'OpenVPN',
+    //'OpenVPN (Prefer TCP)' => '',
+    //'OpenVPN (Prefer UDP)' => '',
     'OpenVPN Server Log' => 'سجل خادم OpenVPN',
     'Password' => 'كلمة المرور',
     'Permissions' => 'صلاحيات',
     'Please sign in with your username and password.' => 'سجل دخولك من فضلك باستعمال اسم المستخدم وكلمة المرور.',
     'Port' => 'منفذ',
     'Ports' => 'منافذ',
-    'Prefer connecting over TCP (OpenVPN)' => 'تفضيل الاتصال عبر ميثاق التحكم بالنقل (OpenVPN)',
     'Preferred Protocol' => 'الميثاق المفضل',
     'Profile' => 'مظهر',
-    'Profile Default' => 'مظهر اصلي',
+    //'Profile ID' => '',
     'Profile Usage' => 'استعمال المظهر',
     'Profile(s)' => 'المظاهر',
     'Public Key' => 'مفتاح عام',
+    //'Refresh' => '',
     'Results' => 'نتائج',
     'Revoke' => 'سحب',
     'Route(s)' => 'وجهات',
@@ -133,7 +134,6 @@ return [
     'This user does not have any active configurations.' => 'هذا المستخدم ليس لديه اي اعدادات نشطة.',
     'This user does not have any connections.' => 'هذا المستخدم ليس لديه اي اتصالات.',
     'To prevent malicious applications from secretly establishing a VPN connection on your behalf, you have to explicitly approve this application first.' => 'لمنع التطبيقات الضارة من الاتصال بالشبكة الخاصة الافتراضية نيابة عنك، عليك الموافقة  صراحة على هذا التطبيق اولا.',
-    'Use Protocol' => 'استخدم ميثاق',
     'Use the WireGuard app on your mobile device to scan this QR code.' => 'استخدم تطبيق وايرجارد على جوالك لمسح رمز الاستجابة السريعة.',
     'User ID' => 'هوية المستخدم',
     'Username' => 'اسم المستخدم',
