@@ -19,7 +19,6 @@ return [
     'Account' => '',
     'Active' => '',
     'Active Configurations' => '',
-    'Advanced' => '',
     'Aggregated' => '',
     'All' => '',
     'An application attempts to establish a VPN connection.' => '',
@@ -96,19 +95,21 @@ return [
     'Online' => '',
     'Only approve this when you are trying to establish a VPN connection with this application!' => '',
     'OpenVPN' => '',
+    'OpenVPN (Prefer TCP)' => '',
+    'OpenVPN (Prefer UDP)' => '',
     'OpenVPN Server Log' => '',
     'Password' => '',
     'Permissions' => '',
     'Please sign in with your username and password.' => '',
     'Port' => '',
     'Ports' => '',
-    'Prefer connecting over TCP (OpenVPN)' => '',
     'Preferred Protocol' => '',
     'Profile' => '',
-    'Profile Default' => '',
+    'Profile ID' => '',
     'Profile Usage' => '',
     'Profile(s)' => '',
     'Public Key' => '',
+    'Refresh' => '',
     'Results' => '',
     'Revoke' => '',
     'Route(s)' => '',
@@ -133,7 +134,6 @@ return [
     'This user does not have any active configurations.' => '',
     'This user does not have any connections.' => '',
     'To prevent malicious applications from secretly establishing a VPN connection on your behalf, you have to explicitly approve this application first.' => '',
-    'Use Protocol' => '',
     'Use the WireGuard app on your mobile device to scan this QR code.' => '',
     'User ID' => '',
     'Username' => '',
