@@ -19,7 +19,6 @@ return [
     'Account' => 'Konto',
     'Active' => 'Aktiivne',
     'Active Configurations' => 'Aktiivsed seadistused',
-    'Advanced' => 'Täpsemad',
     'Aggregated' => 'Koondatud',
     'All' => 'Kõik',
     'An application attempts to establish a VPN connection.' => 'Rakendus proovib luua VPN ühendust.',
@@ -96,19 +95,21 @@ return [
     'Online' => 'Võrguühendusega',
     'Only approve this when you are trying to establish a VPN connection with this application!' => 'Luba rakendus ainult juhul, kui püüad sellega VPN-ühendust luua!',
     'OpenVPN' => 'OpenVPN',
+    //'OpenVPN (Prefer TCP)' => '',
+    //'OpenVPN (Prefer UDP)' => '',
     'OpenVPN Server Log' => 'OpenVPN serveri logi',
     'Password' => 'Parool',
     'Permissions' => 'Õigused',
     'Please sign in with your username and password.' => 'Palun logi oma kasutajanime ja parooliga sisse.',
     'Port' => 'Port',
     'Ports' => 'Pordid',
-    'Prefer connecting over TCP (OpenVPN)' => 'Eelistatud on ühendumine TCPga (OpenVPN)',
     'Preferred Protocol' => 'Eelistatud protokoll',
     'Profile' => 'Profiil',
-    'Profile Default' => 'Vaikeprofiil',
+    //'Profile ID' => '',
     'Profile Usage' => 'Profiili kasutus',
     'Profile(s)' => 'Profiil(id)',
     'Public Key' => 'Avalik võti',
+    //'Refresh' => '',
     'Results' => 'Tulemused',
     'Revoke' => 'Tühista',
     'Route(s)' => 'Marsruut/marsruudid',
@@ -133,7 +134,6 @@ return [
     'This user does not have any active configurations.' => 'Sel kasutajal ei ole aktiivseid ühendusi.',
     'This user does not have any connections.' => 'Sel kasutajal ei ole ühendusi.',
     'To prevent malicious applications from secretly establishing a VPN connection on your behalf, you have to explicitly approve this application first.' => 'Vältimaks kahjurrakenduste poolt Sinu nimel salaja VPN ühenduste loomist, pead selle rakenduse esmalt ilmutatult heaks kiitma.',
-    'Use Protocol' => 'Kasuta protokolli',
     'Use the WireGuard app on your mobile device to scan this QR code.' => 'Selle QR koodi skaneerimiseks kasuta oma mobiiliseadmes WireGuardi rakendust.',
     'User ID' => 'Kasutaja ID',
     'Username' => 'Kasutajanimi',
