@@ -19,7 +19,6 @@ return [
     'Account' => 'Compte',
     'Active' => 'Active',
     'Active Configurations' => 'Configurations Actives',
-    'Advanced' => 'Avancé',
     'Aggregated' => 'Regroupé',
     'All' => 'Tout',
     'An application attempts to establish a VPN connection.' => 'Une application essaie d\'établir une connexion VPN.',
@@ -96,19 +95,21 @@ return [
     'Online' => 'En ligne',
     'Only approve this when you are trying to establish a VPN connection with this application!' => 'N\'approuvez ceci que lorsque vous essayez d\'établir une connexion VPN avec cette application',
     'OpenVPN' => 'OpenVPN',
+    //'OpenVPN (Prefer TCP)' => '',
+    //'OpenVPN (Prefer UDP)' => '',
     'OpenVPN Server Log' => 'Journal du serveur OpenVPN',
     'Password' => 'Mot de passe',
     'Permissions' => 'Autorisations',
     'Please sign in with your username and password.' => 'Veuillez saisir votre identifiant et votre mot de passe.',
     'Port' => 'Port',
     'Ports' => 'Ports',
-    'Prefer connecting over TCP (OpenVPN)' => 'Préférence de connexion en TCP (OpenVPN)',
     'Preferred Protocol' => 'Protocole préféré',
     'Profile' => 'Profil',
-    'Profile Default' => 'Profil par défaut',
+    //'Profile ID' => '',
     'Profile Usage' => 'Utilisation du profil',
     'Profile(s)' => 'Profil(s)',
     'Public Key' => 'Clé publique',
+    //'Refresh' => '',
     'Results' => 'Résultats',
     'Revoke' => 'Révoquer',
     'Route(s)' => 'Route(s)',
@@ -133,7 +134,6 @@ return [
     'This user does not have any active configurations.' => 'Cet utilisateur n\'a aucune configuration active.',
     'This user does not have any connections.' => 'Cet utilisateur n\'a aucune connexion.',
     'To prevent malicious applications from secretly establishing a VPN connection on your behalf, you have to explicitly approve this application first.' => 'Pour éviter que des applications établissent secrètement une connexion VPN en votre nom, vous devez d\'abord approuver cette application explicitement.',
-    'Use Protocol' => 'Utiliser le protocole',
     'Use the WireGuard app on your mobile device to scan this QR code.' => 'Utilisez l\'app WireGuard sur votre appareil mobile afin de scanner ce code QR.',
     'User ID' => 'Identifiant utilisateur',
     'Username' => 'Identifiant',
