@@ -19,7 +19,6 @@ return [
     'Account' => 'Konto',
     'Active' => 'Aktiv',
     'Active Configurations' => 'Aktive konfigurasjoner',
-    'Advanced' => 'Avansert',
     'Aggregated' => 'Aggregert',
     'All' => 'Alle',
     'An application attempts to establish a VPN connection.' => 'En applikasjon prøver å koble til VPN.',
@@ -96,19 +95,21 @@ return [
     'Online' => 'Online',
     'Only approve this when you are trying to establish a VPN connection with this application!' => 'Kun tillat dette dersom du ønsker å koble til VPN med denne applikasjonen!',
     'OpenVPN' => 'OpenVPN',
+    //'OpenVPN (Prefer TCP)' => '',
+    //'OpenVPN (Prefer UDP)' => '',
     'OpenVPN Server Log' => 'OpenVPN tjener logg',
     'Password' => 'Passord',
     'Permissions' => 'Tillatelser',
     'Please sign in with your username and password.' => 'Logg inn med ditt brukernavn og passord.',
     'Port' => 'Port',
     'Ports' => 'Porter',
-    'Prefer connecting over TCP (OpenVPN)' => 'Foretrekk tilkobling med TCP (OpenVPN)',
     'Preferred Protocol' => 'Foretrukket protokoll',
     'Profile' => 'Profil',
-    'Profile Default' => 'Standard profil',
+    //'Profile ID' => '',
     'Profile Usage' => 'Profil bruk',
     'Profile(s)' => 'Profil(er)',
     'Public Key' => 'Offentlig nøkkel',
+    //'Refresh' => '',
     'Results' => 'Resultater',
     'Revoke' => 'Tilbakekall',
     'Route(s)' => 'Rute(r)',
@@ -133,7 +134,6 @@ return [
     'This user does not have any active configurations.' => 'Bruker har ingen aktiv konfigurasjon',
     'This user does not have any connections.' => 'Bruker har ingen aktive forbindelser',
     'To prevent malicious applications from secretly establishing a VPN connection on your behalf, you have to explicitly approve this application first.' => 'For å forhindre at onde applikasjoner kan koble til VPN på din vegne i hemmelighet, må du eksplisitt tillate denne applikasjonen først.',
-    'Use Protocol' => 'Bruk protokoll',
     'Use the WireGuard app on your mobile device to scan this QR code.' => 'Skann denne QR-koden med WireGuard app på mobilen',
     'User ID' => 'Bruker-ID',
     'Username' => 'Brukernavn',
