@@ -19,7 +19,6 @@ return [
     'Account' => 'Account',
     'Active' => 'Actief',
     'Active Configurations' => 'Actieve configuraties',
-    'Advanced' => 'Geavanceerd',
     'Aggregated' => 'Geaggregeerd',
     'All' => 'Alle',
     'An application attempts to establish a VPN connection.' => 'Een applicatie probeert een VPN-verbinding op te zetten.',
@@ -96,19 +95,21 @@ return [
     'Online' => 'Online',
     'Only approve this when you are trying to establish a VPN connection with this application!' => 'Sta dit alleen toe als je probeert een VPN-verbinding op te zetten met deze applicatie!',
     'OpenVPN' => 'OpenVPN',
+    'OpenVPN (Prefer TCP)' => 'OpenVPN (Voorkeur voor TCP)',
+    'OpenVPN (Prefer UDP)' => 'OpenVPN (Voorkeur voor UDP)',
     'OpenVPN Server Log' => 'OpenVPN server log',
     'Password' => 'Wachtwoord',
     'Permissions' => 'Permissies',
     'Please sign in with your username and password.' => 'Log in met je gebruikersnaam en wachtwoord.',
     'Port' => 'Poort',
     'Ports' => 'Poorten',
-    'Prefer connecting over TCP (OpenVPN)' => 'Geef voorkeur aan verbinden over TCP (OpenVPN)',
     'Preferred Protocol' => 'Voorkeursprotocol',
     'Profile' => 'Profiel',
-    'Profile Default' => 'Profielvoorkeur',
+    'Profile ID' => 'Profiel-ID',
     'Profile Usage' => 'Profielgebruik',
     'Profile(s)' => 'Profiel(en)',
     'Public Key' => 'Public Key',
+    'Refresh' => 'Verversen',
     'Results' => 'Resultaten',
     'Revoke' => 'Intrekken',
     'Route(s)' => 'Route(s)',
@@ -133,7 +134,6 @@ return [
     'This user does not have any active configurations.' => 'Deze gebruiker heeft geen actieve configuraties.',
     'This user does not have any connections.' => 'Deze gebruiker heeft geen verbindingen.',
     'To prevent malicious applications from secretly establishing a VPN connection on your behalf, you have to explicitly approve this application first.' => 'Om te voorkomen dat kwaadaardige applicaties namens jou in het geheim een VPN-verbinding op kunnen zetten moet je dit eerst expliciet toestaan.',
-    'Use Protocol' => 'Protocol',
     'Use the WireGuard app on your mobile device to scan this QR code.' => 'Gebruik de WireGuard-applicatie op je mobiele device om deze QR-code te scannen.',
     'User ID' => 'Gebruikers-ID',
     'Username' => 'Gebruikersnaam',
