@@ -19,7 +19,6 @@ return [
     'Account' => 'Conta',
     'Active' => 'Ativo',
     'Active Configurations' => 'Configurações Ativas',
-    'Advanced' => 'Avançado',
     'Aggregated' => 'Agregado',
     'All' => 'Todos',
     'An application attempts to establish a VPN connection.' => 'Uma aplicação está a tentar estabelecer uma ligação VPN.',
@@ -96,19 +95,21 @@ return [
     'Online' => 'Online',
     'Only approve this when you are trying to establish a VPN connection with this application!' => 'Aprove apenas se estiver a tentar estabelecer uma ligação VPN com esta aplicação.',
     'OpenVPN' => 'OpenVPN',
+    //'OpenVPN (Prefer TCP)' => '',
+    //'OpenVPN (Prefer UDP)' => '',
     'OpenVPN Server Log' => 'Registo de OpenVPN no Servidor',
     'Password' => 'Palavra-passe',
     'Permissions' => 'Acessos',
     'Please sign in with your username and password.' => 'Por favor autentique-se com o seu nome de utilizador e palavra-passe.',
     'Port' => 'Porta',
     'Ports' => 'Portas',
-    'Prefer connecting over TCP (OpenVPN)' => 'Prefira ligar-se através de TCP (OpenVPN)',
     'Preferred Protocol' => 'Protocolo Preferido',
     'Profile' => 'Perfil',
-    'Profile Default' => 'Perfil padrão',
+    //'Profile ID' => '',
     'Profile Usage' => 'Utilização de Perfil',
     'Profile(s)' => 'Perfil(is)',
     'Public Key' => 'Chave Pública',
+    //'Refresh' => '',
     'Results' => 'Resultados',
     'Revoke' => 'Revogar',
     'Route(s)' => 'Rota(s)',
@@ -133,7 +134,6 @@ return [
     'This user does not have any active configurations.' => 'Este utilizador não tem nenhumas configurações ativas.',
     'This user does not have any connections.' => 'Este utilizador não tem nenhumas ligações.',
     'To prevent malicious applications from secretly establishing a VPN connection on your behalf, you have to explicitly approve this application first.' => 'Para impedir que aplicações maliciosas estabeleçam secretamente uma ligação VPN em seu nome, tem de aprovar explicitamente esta aplicação.',
-    'Use Protocol' => 'Use o Protocolo',
     'Use the WireGuard app on your mobile device to scan this QR code.' => 'Use a aplicação WireGuard no seu dispositivo móvel para ler este código QR',
     'User ID' => 'ID de Utilizador',
     'Username' => 'Nome de Utilizador',
