@@ -19,7 +19,6 @@ return [
     'Account' => 'Cont',
     'Active' => 'Activ',
     'Active Configurations' => 'Configurații active',
-    'Advanced' => 'Avansat',
     'Aggregated' => 'Agregat',
     'All' => 'Toate',
     'An application attempts to establish a VPN connection.' => 'O aplicație încearcă să stabilească o conexiune VPN.',
@@ -96,19 +95,21 @@ return [
     'Online' => 'Online',
     'Only approve this when you are trying to establish a VPN connection with this application!' => 'Aprobă acest lucru numai atunci când încerci să stabilești o conexiune VPN cu această aplicație!',
     'OpenVPN' => 'OpenVPN',
+    //'OpenVPN (Prefer TCP)' => '',
+    //'OpenVPN (Prefer UDP)' => '',
     'OpenVPN Server Log' => 'OpenVPN Server Log',
     'Password' => 'Parolă',
     'Permissions' => 'Permisiuni',
     'Please sign in with your username and password.' => 'Conectează-te cu numele și parola ta de utilizator.',
     'Port' => 'Port',
     'Ports' => 'Porturi',
-    'Prefer connecting over TCP (OpenVPN)' => 'Prefer conectarea prin TCP (OpenVPN)',
     'Preferred Protocol' => 'Protocolul preferat',
     'Profile' => 'Profil',
-    'Profile Default' => 'Profil implicit',
+    //'Profile ID' => '',
     'Profile Usage' => 'Utilizarea profilului',
     'Profile(s)' => 'Profil(e)',
     'Public Key' => 'Cheie publică',
+    //'Refresh' => '',
     'Results' => 'Rezultate',
     'Revoke' => 'Revocă',
     'Route(s)' => 'Rute',
@@ -133,7 +134,6 @@ return [
     'This user does not have any active configurations.' => 'Acest utilizator nu are nicio configurație activă.',
     'This user does not have any connections.' => 'Acest utilizator nu are realizată nicio conexiune.',
     'To prevent malicious applications from secretly establishing a VPN connection on your behalf, you have to explicitly approve this application first.' => 'Pentru a preveni aplicațiile rău intenționate să stabilească în secret o conexiune VPN în numele tău, trebuie să aprobi în mod explicit această aplicație.',
-    'Use Protocol' => 'Utilizați protocolul',
     'Use the WireGuard app on your mobile device to scan this QR code.' => 'Utilizați aplicația WireGuard de pe dispozitivul dvs. mobil pentru a scana acest cod QR.',
     'User ID' => 'Cod de identificare (ID) utilizator',
     'Username' => 'Nume de utilizator',
