@@ -19,7 +19,6 @@ return [
     'Account' => 'Konto',
     'Active' => 'Aktiv',
     'Active Configurations' => 'Aktiva konfigurationer',
-    'Advanced' => 'Avancerad',
     'Aggregated' => 'Aggregerad',
     'All' => 'Alla',
     'An application attempts to establish a VPN connection.' => 'Ett program försöker upprätta en VPN-anslutning.',
@@ -96,19 +95,21 @@ return [
     'Online' => 'Online',
     'Only approve this when you are trying to establish a VPN connection with this application!' => 'Godkänn bara detta när du försöker upprätta en VPN-anslutning med den här applikationen!',
     'OpenVPN' => 'OpenVPN',
+    //'OpenVPN (Prefer TCP)' => '',
+    //'OpenVPN (Prefer UDP)' => '',
     'OpenVPN Server Log' => 'OpenVPN Server Log',
     'Password' => 'Lösenord',
     'Permissions' => 'Behörigheter',
     'Please sign in with your username and password.' => 'Logga in med ditt användarnamn och lösenord.',
     'Port' => 'Port',
     'Ports' => 'Portar',
-    'Prefer connecting over TCP (OpenVPN)' => 'Föredrar att ansluta via TCP (OpenVPN)',
     'Preferred Protocol' => 'Önskat protokoll',
     'Profile' => 'Profil',
-    'Profile Default' => 'Standardprofil',
+    //'Profile ID' => '',
     'Profile Usage' => 'Profilanvändning',
     'Profile(s)' => 'Profil(er)',
     'Public Key' => 'Publik nyckel',
+    //'Refresh' => '',
     'Results' => 'Resultat',
     'Revoke' => 'Återkalla',
     'Route(s)' => 'Route(s)',
@@ -133,7 +134,6 @@ return [
     'This user does not have any active configurations.' => 'Den här användaren har inga aktiva konfigurationer.',
     'This user does not have any connections.' => 'Den här användaren har inga anslutningar.',
     'To prevent malicious applications from secretly establishing a VPN connection on your behalf, you have to explicitly approve this application first.' => 'För att förhindra att skadliga program i hemlighet upprättar en VPN-anslutning för din räkning måste du uttryckligen godkänna det här programmet först.',
-    'Use Protocol' => 'Använd protokoll',
     'Use the WireGuard app on your mobile device to scan this QR code.' => 'Använd WireGuard-appen på din mobila enhet för att skanna denna QR-kod.',
     'User ID' => 'Användar-ID',
     'Username' => 'Användarnamn',
