@@ -34,6 +34,14 @@ class ApiConfig
         $this->configData = $configData;
     }
 
+    /**
+     * @return array<string>
+     */
+    public function appSets(): array
+    {
+        return $this->requireStringArray('appSets', ['eduVPN', 'LC']);
+    }
+
     /**
      * OAuth "access_token" expiry.
      */
