@@ -40,7 +40,7 @@ class ProfileConfig
         $nodeIndex = $this->nodeNumberToIndex($nodeNumber);
         $hostNameList = $this->requireStringOrStringArray('hostName');
         if ($nodeIndex >= \count($hostNameList)) {
-            throw new ConfigException('"hostName" for node "'.$nodeNumber.'" not set');
+            throw new ConfigException('"hostName" for node "' . $nodeNumber . '" not set');
         }
 
         return $hostNameList[$nodeIndex];
@@ -88,7 +88,7 @@ class ProfileConfig
      */
     public function dnsSearchDomainList(): array
     {
-        return array_unique($this->requireStringArray('dnsSearchDomainList', []));
+        return $this->requireStringArray('dnsSearchDomainList', []);
     }
 
     public function nodeUrl(int $nodeNumber): string
@@ -96,7 +96,7 @@ class ProfileConfig
         $nodeIndex = $this->nodeNumberToIndex($nodeNumber);
         $nodeUrlList = $this->requireStringOrStringArray('nodeUrl', ['http://localhost:41194']);
         if ($nodeIndex >= \count($nodeUrlList)) {
-            throw new ConfigException('"nodeUrl" for node "'.$nodeNumber.'" not set');
+            throw new ConfigException('"nodeUrl" for node "' . $nodeNumber . '" not set');
         }
 
         return $nodeUrlList[$nodeIndex];
@@ -128,7 +128,7 @@ class ProfileConfig
         $nodeIndex = $this->nodeNumberToIndex($nodeNumber);
         $wRangeFourList = $this->requireStringOrStringArray('wRangeFour');
         if ($nodeIndex >= \count($wRangeFourList)) {
-            throw new ConfigException('"wRangeFour" for node "'.$nodeNumber.'" not set');
+            throw new ConfigException('"wRangeFour" for node "' . $nodeNumber . '" not set');
         }
 
         return Ip::fromIpPrefix($wRangeFourList[$nodeIndex]);
@@ -139,7 +139,7 @@ class ProfileConfig
         $nodeIndex = $this->nodeNumberToIndex($nodeNumber);
         $wRangeSixList = $this->requireStringOrStringArray('wRangeSix');
         if ($nodeIndex >= \count($wRangeSixList)) {
-            throw new ConfigException('"wRangeSix" for node "'.$nodeNumber.'" not set');
+            throw new ConfigException('"wRangeSix" for node "' . $nodeNumber . '" not set');
         }
 
         return Ip::fromIpPrefix($wRangeSixList[$nodeIndex]);
@@ -150,7 +150,7 @@ class ProfileConfig
         $nodeIndex = $this->nodeNumberToIndex($nodeNumber);
         $oRangeFourList = $this->requireStringOrStringArray('oRangeFour');
         if ($nodeIndex >= \count($oRangeFourList)) {
-            throw new ConfigException('"oRangeFour" for node "'.$nodeNumber.'" not set');
+            throw new ConfigException('"oRangeFour" for node "' . $nodeNumber . '" not set');
         }
 
         return Ip::fromIpPrefix($oRangeFourList[$nodeIndex]);
@@ -161,7 +161,7 @@ class ProfileConfig
         $nodeIndex = $this->nodeNumberToIndex($nodeNumber);
         $oRangeSixList = $this->requireStringOrStringArray('oRangeSix');
         if ($nodeIndex >= \count($oRangeSixList)) {
-            throw new ConfigException('"oRangeSix" for node "'.$nodeNumber.'" not set');
+            throw new ConfigException('"oRangeSix" for node "' . $nodeNumber . '" not set');
         }
 
         return Ip::fromIpPrefix($oRangeSixList[$nodeIndex]);
@@ -216,7 +216,7 @@ class ProfileConfig
         }
         $nodeIndex = $this->nodeNumberToIndex($nodeNumber);
         if ($nodeIndex >= \count($oListenOnList)) {
-            throw new ConfigException('"oListenOn" for node "'.$nodeNumber.'" not set');
+            throw new ConfigException('"oListenOn" for node "' . $nodeNumber . '" not set');
         }
 
         return Ip::fromIp($oListenOnList[$nodeIndex]);
