@@ -22,6 +22,11 @@ class WireGuardConfig
         $this->configData = $configData;
     }
 
+    public function setMtu(): ?int
+    {
+        return $this->optionalInt('setMtu');
+    }
+
     public function listenPort(): int
     {
         return $this->requireInt('listenPort', 51820);
