@@ -11,6 +11,7 @@ declare(strict_types=1);
 
 namespace Vpn\Portal;
 
+use RangeException;
 use Vpn\Portal\Cfg\Config;
 use Vpn\Portal\Cfg\ProfileConfig;
 
@@ -35,6 +36,7 @@ class ConfigCheck
         // per profile issues
         foreach ($config->profileConfigList() as $profileConfig) {
             $problemList = [];
+            self::verifyValidProfileId($profileConfig, $problemList);
             self::verifyNotSupportedProfileConfigKeys($profileConfig, $problemList);
             self::verifyDefaultGatewayHasDnsServerList($profileConfig, $problemList);
             self::verifyRangeOverlap($profileConfig, $usedRangeList, $problemList);
@@ -67,7 +69,16 @@ class ConfigCheck
     {
         $unsupportedConfigKeys = $config->unsupportedConfigKeys();
         foreach ($unsupportedConfigKeys as $unsupportedConfigKey) {
-            $globalProblemList[] = 'configuration key "'.$unsupportedConfigKey.'" not supported';
+            $globalProblemList[] = 'configuration key "' . $unsupportedConfigKey . '" not supported';
+        }
+    }
+
+    private static function verifyValidProfileId(ProfileConfig $profileConfig, array &$profileProblemList): void
+    {
+        try {
+            Validator::profileId($profileConfig->profileId());
+        } catch (RangeException $e) {
+            $profileProblemList[] = sprintf('"profileId" field has invalid value "%s"', $profileConfig->profileId());
         }
     }
 
@@ -75,7 +86,7 @@ class ConfigCheck
     {
         $unsupportedConfigKeys = $profileConfig->unsupportedConfigKeys();
         foreach ($unsupportedConfigKeys as $unsupportedConfigKey) {
-            $profileProblemList[] = 'configuration key "'.$unsupportedConfigKey.'" not supported';
+            $profileProblemList[] = 'configuration key "' . $unsupportedConfigKey . '" not supported';
         }
     }
 
