@@ -31,24 +31,10 @@ class AccessHook extends AbstractHook implements HookInterface
 
     public function afterAuth(Request $request, UserInfo &$userInfo): ?Response
     {
-        if (!$this->hasPermissions($userInfo->permissionList())) {
+        if (!$userInfo->hasAnyPermission($this->accessPermissionList)) {
             throw new HttpException('your account does not have the required permissions', 403);
         }
 
         return null;
     }
-
-    /**
-     * @param array<string> $userPermissionList
-     */
-    private function hasPermissions(array $userPermissionList): bool
-    {
-        foreach ($userPermissionList as $userPermission) {
-            if (\in_array($userPermission, $this->accessPermissionList, true)) {
-                return true;
-            }
-        }
-
-        return false;
-    }
 }
