@@ -11,6 +11,8 @@ declare(strict_types=1);
 
 namespace Vpn\Portal\Http\Auth;
 
+use fkooman\Radius\Exception\AuthException;
+use fkooman\Radius\RadiusClient;
 use RuntimeException;
 use Vpn\Portal\Cfg\RadiusAuthConfig;
 use Vpn\Portal\Http\Auth\Exception\CredentialValidatorException;
@@ -18,9 +20,6 @@ use Vpn\Portal\Http\Auth\Exception\RadiusException;
 use Vpn\Portal\Http\UserInfo;
 use Vpn\Portal\LoggerInterface;
 
-/**
- * @psalm-suppress UndefinedConstant
- */
 class RadiusCredentialValidator implements CredentialValidatorInterface
 {
     private LoggerInterface $logger;
@@ -28,9 +27,6 @@ class RadiusCredentialValidator implements CredentialValidatorInterface
 
     public function __construct(LoggerInterface $logger, RadiusAuthConfig $radiusAuthConfig)
     {
-        if (false === \extension_loaded('radius')) {
-            throw new RuntimeException('"radius" PHP extension not available');
-        }
         $this->logger = $logger;
         $this->radiusAuthConfig = $radiusAuthConfig;
     }
@@ -50,18 +46,28 @@ class RadiusCredentialValidator implements CredentialValidatorInterface
             $authUser = sprintf('%s@%s', $authUser, $radiusRealm);
         }
 
+        if (extension_loaded('radius')) {
+            return $this->peclRadius($authUser, $authPass);
+        }
+
+        return $this->fkoomanRadius($authUser, $authPass);
+    }
+
+    /**
+     * @psalm-suppress UndefinedConstant
+     */
+    private function peclRadius(string $authUser, string $authPass): UserInfo
+    {
+        if (0 === count($this->radiusAuthConfig->serverList())) {
+            throw new RuntimeException('no RADIUS servers configured');
+        }
         $radiusAuth = radius_auth_open();
         foreach ($this->radiusAuthConfig->serverList() as $radiusServer) {
-            $radiusInfo = explode(':', $radiusServer, 3);
-            if (3 !== count($radiusInfo)) {
-                throw new RadiusException('invalid RADIUS `serverList` entry, format: `host:port:secret`');
-            }
-            [$radiusHost, $radiusPort, $radiusSecret] = $radiusInfo;
             if (false === radius_add_server(
                 $radiusAuth,
-                $radiusHost,
-                (int) $radiusPort,
-                $radiusSecret,
+                $radiusServer['radiusHost'],
+                $radiusServer['radiusPort'],
+                $radiusServer['radiusSecret'],
                 5,  // timeout
                 3   // max_tries
             )) {
@@ -114,4 +120,41 @@ class RadiusCredentialValidator implements CredentialValidatorInterface
 
         return new UserInfo($authUser, $permissionList);
     }
+
+    private function fkoomanRadius(string $authUser, string $authPass): UserInfo
+    {
+        if (0 === count($this->radiusAuthConfig->serverList())) {
+            throw new RuntimeException('no (valid) RADIUS servers configured');
+        }
+
+        $nasIdentifier = $this->radiusAuthConfig->nasIdentifier() ?? 'vpn';
+        $radiusAuth = new RadiusClient($nasIdentifier);
+        foreach ($this->radiusAuthConfig->serverList() as $radiusServer) {
+            $radiusAuth->addServer($radiusServer['radiusHost'], $radiusServer['radiusSecret'], $radiusServer['radiusPort']);
+        }
+
+        try {
+            $accessResponse = $radiusAuth->accessRequest($authUser, $authPass);
+            $permissionList = [];
+
+            // if config asked for a permission attribute, we check whether it
+            // is available
+            if (null !== $permissionAttribute = $this->radiusAuthConfig->permissionAttribute()) {
+                if (null !== $attributeValue = $accessResponse->attributeByType($permissionAttribute)) {
+                    $permissionList[] = $attributeValue;
+                }
+            }
+
+            // if the server provides us with a normalized User-Name, we use
+            // it. Might be relevant for LDAP backends which might be case
+            // insenstive
+            if (null !== $userName = $accessResponse->attributeByName('User-Name')) {
+                $authUser = $userName;
+            }
+
+            return new UserInfo($authUser, $permissionList);
+        } catch (AuthException $e) {
+            throw new CredentialValidatorException('authentication not accepted');
+        }
+    }
 }
