@@ -28,23 +28,23 @@ class ShibAuthModule extends AbstractAuthModule
 
     public function userInfo(Request $request): ?UserInfo
     {
-        $permissionList = [];
+        $attributeNameValueList = [];
         foreach ($this->config->permissionAttributeList() as $permissionAttribute) {
-            if (null !== $permissionAttributeValue = $request->optionalHeader($permissionAttribute)) {
-                $permissionList = array_merge($permissionList, explode(';', $permissionAttributeValue));
+            if (null !== $attributeNameValue = $request->optionalHeader($permissionAttribute)) {
+                $attributeNameValueList[$permissionAttribute] = explode(';', $attributeNameValue);
             }
         }
 
         return new UserInfo(
             $request->requireHeader($this->config->userIdAttribute()),
-            $permissionList
+            self::flattenPermissionList($attributeNameValueList, $this->config->permissionAttributeList())
         );
     }
 
     public function triggerLogout(Request $request): Response
     {
         return new RedirectResponse(
-            $request->getScheme().'://'.$request->getAuthority().'/Shibboleth.sso/Logout?'.http_build_query(['return' => $request->requireReferrer()])
+            $request->getScheme() . '://' . $request->getAuthority() . '/Shibboleth.sso/Logout?' . http_build_query(['return' => $request->requireReferrer()])
         );
     }
 }
