@@ -12,7 +12,6 @@ declare(strict_types=1);
 namespace Vpn\Portal\Http;
 
 use Vpn\Portal\Http\Exception\HttpException;
-use Vpn\Portal\Storage;
 
 /**
  * This hook is used to check if a user is disabled before allowing any other
@@ -20,16 +19,9 @@ use Vpn\Portal\Storage;
  */
 class DisabledUserHook extends AbstractHook implements HookInterface
 {
-    private Storage $storage;
-
-    public function __construct(Storage $storage)
-    {
-        $this->storage = $storage;
-    }
-
     public function afterAuth(Request $request, UserInfo &$userInfo): ?Response
     {
-        if ($this->storage->userIsDisabled($userInfo->userId())) {
+        if ($userInfo->isDisabled()) {
             throw new HttpException('your account has been disabled by an administrator', 403);
         }
 
