@@ -43,7 +43,7 @@ class NodeApiModule implements ServiceModuleInterface
             function (Request $request, UserInfo $userInfo): Response {
                 // XXX catch exceptions
                 $profileConfigList = $this->config->profileConfigList();
-                $profileIdList = $request->optionalArrayPostParameter('profile_id_list', fn (array $a) => Validator::profileIdList($a));
+                $profileIdList = $request->optionalArrayPostParameter('profile_id_list', fn(array $a) => Validator::profileIdList($a));
                 if (0 !== \count($profileIdList)) {
                     $profileConfigList = [];
                     foreach ($profileIdList as $profileId) {
@@ -54,10 +54,10 @@ class NodeApiModule implements ServiceModuleInterface
                 $serverConfigList = $this->serverConfig->get(
                     $profileConfigList,
                     (int) $userInfo->userId(), // userId = nodeNumber
-                    $request->requirePostParameter('public_key', fn (string $s) => Validator::publicKey($s)),
-                    'yes' === $request->requirePostParameter('prefer_aes', fn (string $s) => Validator::yesOrNo($s)),
-                    $request->requirePostParameter('vpn_user', fn (string $s) => Validator::vpnUser($s)),
-                    $request->requirePostParameter('vpn_group', fn (string $s) => Validator::vpnGroup($s))
+                    $request->requirePostParameter('public_key', fn(string $s) => Validator::publicKey($s)),
+                    'yes' === $request->requirePostParameter('prefer_aes', fn(string $s) => Validator::yesOrNo($s)),
+                    $request->requirePostParameter('vpn_user', fn(string $s) => Validator::vpnUser($s)),
+                    $request->requirePostParameter('vpn_group', fn(string $s) => Validator::vpnGroup($s))
                 );
 
                 return new JsonResponse($serverConfigList);
@@ -66,24 +66,24 @@ class NodeApiModule implements ServiceModuleInterface
 
         $service->post(
             '/connect',
-            fn (Request $request, UserInfo $userInfo): Response => $this->connect($request)
+            fn(Request $request, UserInfo $userInfo): Response => $this->connect($request)
         );
 
         $service->post(
             '/disconnect',
-            fn (Request $request, UserInfo $userInfo): Response => $this->disconnect($request)
+            fn(Request $request, UserInfo $userInfo): Response => $this->disconnect($request)
         );
     }
 
     public function connect(Request $request): Response
     {
         try {
-            $profileId = $request->requirePostParameter('profile_id', fn (string $s) => Validator::profileId($s));
-            $nodeNumber = (int) $request->requireHeader('HTTP_X_NODE_NUMBER', fn (string $s) => Validator::nodeNumber($s));
-            $commonName = $request->requirePostParameter('common_name', fn (string $s) => Validator::commonName($s));
-            $originatingIp = $request->requirePostParameter('originating_ip', fn (string $s) => Validator::ipAddress($s));
-            $ipFour = $request->requirePostParameter('ip_four', fn (string $s) => Validator::ipFour($s));
-            $ipSix = $request->requirePostParameter('ip_six', fn (string $s) => Validator::ipSix($s));
+            $profileId = $request->requirePostParameter('profile_id', fn(string $s) => Validator::profileId($s));
+            $nodeNumber = (int) $request->requireHeader('HTTP_X_NODE_NUMBER', fn(string $s) => Validator::nodeNumber($s));
+            $commonName = $request->requirePostParameter('common_name', fn(string $s) => Validator::commonName($s));
+            $originatingIp = $request->requirePostParameter('originating_ip', fn(string $s) => Validator::ipAddress($s));
+            $ipFour = $request->requirePostParameter('ip_four', fn(string $s) => Validator::ipFour($s));
+            $ipSix = $request->requirePostParameter('ip_six', fn(string $s) => Validator::ipSix($s));
             $userId = $this->verifyConnection($profileId, $nodeNumber, $commonName);
             $this->connectionHook->connect($userId, $profileId, 'openvpn', $commonName, $ipFour, $ipSix, $originatingIp);
 
@@ -97,12 +97,12 @@ class NodeApiModule implements ServiceModuleInterface
 
     public function disconnect(Request $request): Response
     {
-        $profileId = $request->requirePostParameter('profile_id', fn (string $s) => Validator::profileId($s));
-        $commonName = $request->requirePostParameter('common_name', fn (string $s) => Validator::commonName($s));
-        $ipFour = $request->requirePostParameter('ip_four', fn (string $s) => Validator::ipFour($s));
-        $ipSix = $request->requirePostParameter('ip_six', fn (string $s) => Validator::ipSix($s));
-        $bytesIn = (int) $request->requirePostParameter('bytes_in', fn (string $s) => Validator::nonNegativeInt($s));
-        $bytesOut = (int) $request->requirePostParameter('bytes_out', fn (string $s) => Validator::nonNegativeInt($s));
+        $profileId = $request->requirePostParameter('profile_id', fn(string $s) => Validator::profileId($s));
+        $commonName = $request->requirePostParameter('common_name', fn(string $s) => Validator::commonName($s));
+        $ipFour = $request->requirePostParameter('ip_four', fn(string $s) => Validator::ipFour($s));
+        $ipSix = $request->requirePostParameter('ip_six', fn(string $s) => Validator::ipSix($s));
+        $bytesIn = (int) $request->requirePostParameter('bytes_in', fn(string $s) => Validator::nonNegativeInt($s));
+        $bytesOut = (int) $request->requirePostParameter('bytes_out', fn(string $s) => Validator::nonNegativeInt($s));
         // because OpenVPN disconnects are only triggered after the client
         // disconnects from the OpenVPN server process, we can't always use
         // the "certificates" table to find the user_id from there as the
@@ -147,23 +147,11 @@ class NodeApiModule implements ServiceModuleInterface
             if (null === $userInfo = $this->storage->userInfo($userId)) {
                 throw new NodeApiException(sprintf('account "%s" does not exist', $userId));
             }
-            if (false === self::hasPermission($userInfo->permissionList(), $profilePermissionList)) {
+            if (!$userInfo->hasAnyPermission($profilePermissionList)) {
                 throw new NodeApiException(sprintf('account "%s" has insufficient permissions to access profile "%s"', $userId, $profileId));
             }
         }
 
         return $userId;
     }
-
-    private static function hasPermission(array $userPermissionList, array $aclPermissionList): bool
-    {
-        // one of the permissions must be listed in the profile ACL list
-        foreach ($userPermissionList as $userPermission) {
-            if (\in_array($userPermission, $aclPermissionList, true)) {
-                return true;
-            }
-        }
-
-        return false;
-    }
 }
