@@ -19,6 +19,7 @@ use Vpn\Portal\Dt;
 use Vpn\Portal\Exception\ConnectionManagerException;
 use Vpn\Portal\Exception\ProtocolException;
 use Vpn\Portal\Http\Exception\HttpException;
+use Vpn\Portal\PermissionSourceManager;
 use Vpn\Portal\Protocol;
 use Vpn\Portal\ServerInfo;
 use Vpn\Portal\Storage;
@@ -32,8 +33,9 @@ class VpnApiThreeModule implements ApiServiceModuleInterface
     private OAuthStorage $oauthStorage;
     private ServerInfo $serverInfo;
     private ConnectionManager $connectionManager;
+    private PermissionSourceManager $permissionSourceManager;
 
-    public function __construct(Config $config, Storage $storage, OAuthStorage $oauthStorage, ServerInfo $serverInfo, ConnectionManager $connectionManager)
+    public function __construct(Config $config, Storage $storage, OAuthStorage $oauthStorage, ServerInfo $serverInfo, ConnectionManager $connectionManager, PermissionSourceManager $permissionSourceManager)
     {
         $this->config = $config;
         $this->storage = $storage;
@@ -41,6 +43,7 @@ class VpnApiThreeModule implements ApiServiceModuleInterface
         $this->serverInfo = $serverInfo;
         $this->connectionManager = $connectionManager;
         $this->dateTime = Dt::get();
+        $this->permissionSourceManager = $permissionSourceManager;
     }
 
     public function init(ApiServiceInterface $service): void
@@ -52,21 +55,47 @@ class VpnApiThreeModule implements ApiServiceModuleInterface
                 if (null === $dbUserInfo = $this->storage->userInfo($userInfo->userId())) {
                     throw new HttpException(sprintf('user "%s" no longer exists', $userInfo->userId()), 500);
                 }
+
+                if (null !== $permissionList = $this->permissionSourceManager->get($userInfo->userId())) {
+                    // got real-time permissions
+                    $dbUserInfo->setPermissionList($permissionList);
+                }
+
                 $userProfileList = [];
                 foreach ($profileConfigList as $profileConfig) {
                     if (null !== $aclPermissionList = $profileConfig->aclPermissionList()) {
-                        // is the user member of the aclPermissionList?
-                        if (!VpnPortalModule::isMember($aclPermissionList, $dbUserInfo->permissionList())) {
+                        if (!$dbUserInfo->hasAnyPermission($aclPermissionList)) {
                             continue;
                         }
                     }
 
-                    $userProfileList[] = [
+                    $vpnProtoTransportList = [];
+                    if ($profileConfig->oSupport()) {
+                        if (0 !== count($profileConfig->oUdpPortList()) || 0 !== count($profileConfig->oExposedUdpPortList())) {
+                            $vpnProtoTransportList[] = 'openvpn+udp';
+                        }
+                        if (0 !== count($profileConfig->oTcpPortList()) || 0 !== count($profileConfig->oExposedTcpPortList())) {
+                            $vpnProtoTransportList[] = 'openvpn+tcp';
+                        }
+                    }
+                    if ($profileConfig->wSupport()) {
+                        $vpnProtoTransportList[] = 'wireguard+udp';
+                    }
+
+                    $profileInfo = [
                         'profile_id' => $profileConfig->profileId(),
                         'display_name' => $profileConfig->displayName(),
                         'vpn_proto_list' => $profileConfig->protoList(),
                         'default_gateway' => $profileConfig->defaultGateway(),
+                        'vpn_proto_transport_list' => $vpnProtoTransportList,
                     ];
+                    // if defined, add the DNS search domains to the response
+                    $dnsSearchDomainList = $profileConfig->dnsSearchDomainList();
+                    if (0 !== count($dnsSearchDomainList)) {
+                        $profileInfo['dns_search_domain_list'] = $dnsSearchDomainList;
+                    }
+
+                    $userProfileList[] = $profileInfo;
                 }
 
                 return new JsonResponse(
@@ -101,16 +130,21 @@ class VpnApiThreeModule implements ApiServiceModuleInterface
                             $activeApiConfigurations[0]['connection_id']
                         );
                     }
-                    $requestedProfileId = $request->requirePostParameter('profile_id', fn (string $s) => Validator::profileId($s));
+                    $requestedProfileId = $request->requirePostParameter('profile_id', fn(string $s) => Validator::profileId($s));
                     $profileConfigList = $this->config->profileConfigList();
                     if (null === $dbUserInfo = $this->storage->userInfo($userInfo->userId())) {
                         throw new HttpException(sprintf('user "%s" no longer exists', $userInfo->userId()), 500);
                     }
+
+                    if (null !== $permissionList = $this->permissionSourceManager->get($userInfo->userId())) {
+                        // got real-time permissions
+                        $dbUserInfo->setPermissionList($permissionList);
+                    }
+
                     $availableProfiles = [];
                     foreach ($profileConfigList as $profileConfig) {
                         if (null !== $aclPermissionList = $profileConfig->aclPermissionList()) {
-                            // is the user member of the userPermissions?
-                            if (!VpnPortalModule::isMember($aclPermissionList, $dbUserInfo->permissionList())) {
+                            if (!$dbUserInfo->hasAnyPermission($aclPermissionList)) {
                                 continue;
                             }
                         }
@@ -123,15 +157,15 @@ class VpnApiThreeModule implements ApiServiceModuleInterface
                     }
 
                     $profileConfig = $this->config->profileConfig($requestedProfileId);
-                    $publicKey = $request->optionalPostParameter('public_key', fn (string $s) => Validator::publicKey($s));
+                    $publicKey = $request->optionalPostParameter('public_key', fn(string $s) => Validator::publicKey($s));
 
                     // still support "tcp_only" as an alias for "prefer_tcp",
                     // breaks when tcp_only=on and prefer_tcp=no, but we only
                     // want to support old clients (still using tcp_only) and
                     // new clients supporting prefer_tcp, and not a client
                     // where both are used...
-                    $preferTcp = 'on' === $request->optionalPostParameter('tcp_only', fn (string $s) => Validator::onOrOff($s));
-                    $preferTcp = $preferTcp || 'yes' === $request->optionalPostParameter('prefer_tcp', fn (string $s) => Validator::yesOrNo($s));
+                    $preferTcp = 'on' === $request->optionalPostParameter('tcp_only', fn(string $s) => Validator::onOrOff($s));
+                    $preferTcp = $preferTcp || 'yes' === $request->optionalPostParameter('prefer_tcp', fn(string $s) => Validator::yesOrNo($s));
 
                     // XXX if public_key is missing when VPN client supports
                     // WireGuard that is a bug I guess, is the spec clear about
