@@ -20,6 +20,7 @@ use Vpn\Portal\Dt;
 use Vpn\Portal\Expiry;
 use Vpn\Portal\Http\Exception\HttpException;
 use Vpn\Portal\OpenVpn\ClientConfig as OpenVpnClientConfig;
+use Vpn\Portal\PermissionSourceManager;
 use Vpn\Portal\ServerInfo;
 use Vpn\Portal\Storage;
 use Vpn\Portal\Tpl;
@@ -39,8 +40,9 @@ class VpnPortalModule implements ServiceModuleInterface
     private OAuthStorage $oauthStorage;
     private ServerInfo $serverInfo;
     private Expiry $sessionExpiry;
+    private PermissionSourceManager $permissionSourceManager;
 
-    public function __construct(Config $config, TplInterface $tpl, CookieInterface $cookie, ConnectionManager $connectionManager, Storage $storage, OAuthStorage $oauthStorage, ServerInfo $serverInfo, Expiry $sessionExpiry)
+    public function __construct(Config $config, TplInterface $tpl, CookieInterface $cookie, ConnectionManager $connectionManager, Storage $storage, OAuthStorage $oauthStorage, ServerInfo $serverInfo, Expiry $sessionExpiry, PermissionSourceManager $permissionSourceManager)
     {
         $this->config = $config;
         $this->tpl = $tpl;
@@ -50,6 +52,7 @@ class VpnPortalModule implements ServiceModuleInterface
         $this->serverInfo = $serverInfo;
         $this->connectionManager = $connectionManager;
         $this->sessionExpiry = $sessionExpiry;
+        $this->permissionSourceManager = $permissionSourceManager;
         $this->dateTime = Dt::get();
     }
 
@@ -57,14 +60,16 @@ class VpnPortalModule implements ServiceModuleInterface
     {
         $service->get(
             '/',
-            fn (Request $request, UserInfo $userInfo): Response => new RedirectResponse($request->getRootUri().'home')
+            fn(Request $request, UserInfo $userInfo): Response => new RedirectResponse($request->getRootUri() . 'home')
         );
 
         $service->get(
             '/home',
             function (Request $request, UserInfo $userInfo): Response {
                 $profileConfigList = $this->config->profileConfigList();
-                $visibleProfileList = self::filterProfileList($profileConfigList, $userInfo->permissionList());
+                $visibleProfileList = self::filterProfileList($profileConfigList, $userInfo);
+
+                $profileSelectList = self::profileSelectList($visibleProfileList);
 
                 return new HtmlResponse(
                     $this->tpl->render(
@@ -75,6 +80,7 @@ class VpnPortalModule implements ServiceModuleInterface
                             'profileConfigList' => $visibleProfileList,
                             'expiryDate' => $this->sessionExpiry->expiresAt($userInfo)->format('Y-m-d'),
                             'configList' => self::filterConfigList($this->storage, $userInfo->userId()),
+                            'profileSelectList' => $profileSelectList,
                         ]
                     )
                 );
@@ -82,61 +88,42 @@ class VpnPortalModule implements ServiceModuleInterface
         );
 
         $service->post(
-            '/addConfig',
+            '/home',
             function (Request $request, UserInfo $userInfo): Response {
-                $maxActiveConfigurations = $this->config->maxActiveConfigurations();
-                if (0 === $maxActiveConfigurations) {
-                    throw new HttpException('no portal configuration downloads allowed', 403);
-                }
-                $numberOfActivePortalConfigurations = $this->storage->numberOfActivePortalConfigurations($userInfo->userId(), $this->dateTime);
-                if ($numberOfActivePortalConfigurations >= $maxActiveConfigurations) {
-                    throw new HttpException('limit of available portal configuration downloads has been reached', 403);
-                }
-
-                $displayName = $request->requirePostParameter('displayName', fn (string $s) => Validator::displayName($s));
-                $preferTcp = 'on' === $request->optionalPostParameter('preferTcp', fn (string $s) => Validator::onOrOff($s));
-                $profileId = $request->requirePostParameter('profileId', fn (string $s) => Validator::profileId($s));
-                $profileConfigList = $this->config->profileConfigList();
-                $userPermissions = $userInfo->permissionList();
-                $visibleProfileList = self::filterProfileList($profileConfigList, $userPermissions);
-
-                // make sure the profileId is in the list of allowed profiles for this
-                // user, it would not result in the ability to use the VPN, but
-                // better prevent it early
-                if (!$this->isAllowedProfile($visibleProfileList, $profileId)) {
-                    throw new HttpException('no permission to download a configuration for this profile', 403);
-                }
-
-                $profileConfig = $this->config->profileConfig($profileId);
-                $secretKey = Key::generate();
-                $publicKey = Key::publicKeyFromSecretKey($secretKey);
-
-                $clientProtoSupport = self::clientProtoSupport($request->requirePostParameter('useProto', fn (string $s) => Validator::vpnProto($s)));
-                $clientConfig = $this->connectionManager->connect(
-                    $this->serverInfo,
-                    $profileConfig,
-                    $userInfo->userId(),
-                    $clientProtoSupport,
-                    $displayName,
-                    $this->sessionExpiry->expiresAt($userInfo),
-                    $preferTcp,
-                    $publicKey,
-                    null
+                $postAction = $request->requirePostParameter(
+                    'action',
+                    fn(string $s) => Validator::inSet($s, ['add_config', 'delete_config'])
                 );
+                switch ($postAction) {
+                    case 'add_config':
+                        $profileProtoTransport = $request->requirePostParameter('profileId', fn(string $s) => Validator::profileProtoTransport($s));
+                        [$profileId, $protoTransport] = Validator::parseProfileProtoTransport($profileProtoTransport);
+                        switch ($protoTransport) {
+                            case 'ou':  // OpenVPN UDP
+                                $preferTcp = false;
+                                $clientProtoSupport = ['wireguard' => false, 'openvpn' => true];
 
-                return self::clientConfigResponse($clientConfig, $request->getServerName(), $profileId, $displayName, $secretKey);
-            }
-        );
+                                break;
+                            case 'ot':  // OpenVPN TCP
+                                $preferTcp = true;
+                                $clientProtoSupport = ['wireguard' => false, 'openvpn' => true];
 
-        $service->post(
-            '/deleteConfig',
-            function (Request $request, UserInfo $userInfo): Response {
-                $this->connectionManager->disconnectByConnectionId(
-                    $userInfo->userId(),
-                    $request->requirePostParameter('connectionId', fn (string $s) => Validator::connectionId($s))
-                );
+                                break;
+                            case 'wu':  // WireGuard UDP
+                                $preferTcp = false;
+                                $clientProtoSupport = ['wireguard' => true, 'openvpn' => false];
 
-                return new RedirectResponse($request->getRootUri().'home');
+                                break;
+                            default:
+                                throw new HttpException(sprintf('protocol transport "%s" not supported', $protoTransport), 400);
+                        }
+
+                        return $this->addConfig($request, $userInfo, $profileId, $preferTcp, $clientProtoSupport);
+                    case 'delete_config':
+                        return $this->deleteConfig($request, $userInfo);
+                    default:
+                        throw new HttpException(sprintf('unsupported action "%s"', $postAction), 400);
+                }
             }
         );
 
@@ -144,7 +131,7 @@ class VpnPortalModule implements ServiceModuleInterface
             '/account',
             function (Request $request, UserInfo $userInfo): Response {
                 $profileConfigList = $this->config->profileConfigList();
-                $visibleProfileList = self::filterProfileList($profileConfigList, $userInfo->permissionList());
+                $visibleProfileList = self::filterProfileList($profileConfigList, $userInfo);
 
                 return new HtmlResponse(
                     $this->tpl->render(
@@ -153,6 +140,7 @@ class VpnPortalModule implements ServiceModuleInterface
                             'profileConfigList' => $visibleProfileList,
                             'showPermissions' => $this->config->showPermissions(),
                             'userInfo' => $userInfo,
+                            'showRefreshButton' => $this->permissionSourceManager->hasPermissionSources(),
                             'authorizationList' => $this->oauthStorage->getAuthorizations($userInfo->userId()),
                         ]
                     )
@@ -160,11 +148,23 @@ class VpnPortalModule implements ServiceModuleInterface
             }
         );
 
+        $service->post(
+            '/account',
+            function (Request $request, UserInfo $userInfo): Response {
+                if (null !== $permissionList = $this->permissionSourceManager->get($userInfo->userId())) {
+                    $userInfo->setPermissionList($permissionList);
+                    $this->storage->userUpdate($userInfo, $this->dateTime);
+                }
+
+                return new RedirectResponse($request->getRootUri() . 'account');
+            }
+        );
+
         $service->post(
             '/removeClientAuthorization',
             function (Request $request, UserInfo $userInfo): Response {
                 // XXX make sure authKey belongs to current user!
-                $authKey = $request->requirePostParameter('auth_key', fn (string $s) => Validator::authKey($s));
+                $authKey = $request->requirePostParameter('auth_key', fn(string $s) => Validator::authKey($s));
                 if (null === $this->oauthStorage->getAuthorization($authKey)) {
                     throw new HttpException('no such authorization', 400);
                 }
@@ -176,32 +176,20 @@ class VpnPortalModule implements ServiceModuleInterface
                 // delete the OAuth authorization
                 $this->oauthStorage->deleteAuthorization($authKey);
 
-                return new RedirectResponse($request->getRootUri().'account');
+                return new RedirectResponse($request->getRootUri() . 'account');
             }
         );
 
         $service->postBeforeAuth(
             '/setLanguage',
             function (Request $request): Response {
-                $this->cookie->set('L', $request->requirePostParameter('uiLanguage', fn (string $s) => Validator::inSet($s, array_keys(Tpl::supportedLanguages()))));
+                $this->cookie->set('L', $request->requirePostParameter('uiLanguage', fn(string $s) => Validator::inSet($s, array_keys(Tpl::supportedLanguages()))));
 
                 return new RedirectResponse($request->requireReferrer());
             }
         );
     }
 
-    public static function isMember(array $aclPermissionList, array $userPermissions): bool
-    {
-        // if any of the permissions is part of aclPermissionList return true
-        foreach ($userPermissions as $userPermission) {
-            if (\in_array($userPermission, $aclPermissionList, true)) {
-                return true;
-            }
-        }
-
-        return false;
-    }
-
     /**
      * @return list<array{auth_key: null, connection_id: string, display_name: string, expires_at: DateTimeImmutable, ip_four?: string, ip_six?: string, node_number: int, profile_id: string}>
      */
@@ -239,6 +227,59 @@ class VpnPortalModule implements ServiceModuleInterface
         return $configList;
     }
 
+    /**
+     * @param array{wireguard:bool,openvpn:bool} $clientProtoSupport
+     */
+    private function addConfig(Request $request, UserInfo $userInfo, string $profileId, bool $preferTcp, array $clientProtoSupport): Response
+    {
+        $maxActiveConfigurations = $this->config->maxActiveConfigurations();
+        if (0 === $maxActiveConfigurations) {
+            throw new HttpException('no portal configuration downloads allowed', 403);
+        }
+        $numberOfActivePortalConfigurations = $this->storage->numberOfActivePortalConfigurations($userInfo->userId(), $this->dateTime);
+        if ($numberOfActivePortalConfigurations >= $maxActiveConfigurations) {
+            throw new HttpException('limit of available portal configuration downloads has been reached', 403);
+        }
+
+        $displayName = $request->requirePostParameter('displayName', fn(string $s) => Validator::displayName($s));
+        $profileConfigList = $this->config->profileConfigList();
+        $visibleProfileList = self::filterProfileList($profileConfigList, $userInfo);
+
+        // make sure the profileId is in the list of allowed profiles for this
+        // user, it would not result in the ability to use the VPN, but
+        // better prevent it early
+        if (!$this->isAllowedProfile($visibleProfileList, $profileId)) {
+            throw new HttpException('no permission to download a configuration for this profile', 403);
+        }
+
+        $profileConfig = $this->config->profileConfig($profileId);
+        $secretKey = Key::generate();
+        $publicKey = Key::publicKeyFromSecretKey($secretKey);
+        $clientConfig = $this->connectionManager->connect(
+            $this->serverInfo,
+            $profileConfig,
+            $userInfo->userId(),
+            $clientProtoSupport,
+            $displayName,
+            $this->sessionExpiry->expiresAt($userInfo),
+            $preferTcp,
+            $publicKey,
+            null
+        );
+
+        return self::clientConfigResponse($clientConfig, $request->getServerName(), $profileId, $displayName, $secretKey);
+    }
+
+    private function deleteConfig(Request $request, UserInfo $userInfo): Response
+    {
+        $this->connectionManager->disconnectByConnectionId(
+            $userInfo->userId(),
+            $request->requirePostParameter('connectionId', fn(string $s) => Validator::connectionId($s))
+        );
+
+        return new RedirectResponse($request->getRootUri() . 'home');
+    }
+
     private function clientConfigResponse(ClientConfigInterface $clientConfig, string $serverName, string $profileId, string $displayName, string $secretKey): Response
     {
         if ($clientConfig instanceof WireGuardClientConfig) {
@@ -281,13 +322,12 @@ class VpnPortalModule implements ServiceModuleInterface
      *
      * @return array<\Vpn\Portal\Cfg\ProfileConfig>
      */
-    private static function filterProfileList(array $profileConfigList, array $userPermissions): array
+    private static function filterProfileList(array $profileConfigList, UserInfo $userInfo): array
     {
         $filteredProfileConfigList = [];
         foreach ($profileConfigList as $profileConfig) {
             if (null !== $aclPermissionList = $profileConfig->aclPermissionList()) {
-                // is the user member of the aclPermissionList?
-                if (!self::isMember($aclPermissionList, $userPermissions)) {
+                if (!$userInfo->hasAnyPermission($aclPermissionList)) {
                     continue;
                 }
             }
@@ -313,17 +353,41 @@ class VpnPortalModule implements ServiceModuleInterface
     }
 
     /**
-     * @return array{wireguard:bool,openvpn:bool}
+     * @param array<\Vpn\Portal\Cfg\ProfileConfig> $profileConfigList
+     *
+     * @return array{rowCount:int,profileList:array<array{profileId:string,displayName:string,protoTransportList:array<string>}>}
      */
-    private static function clientProtoSupport(string $useProto): array
+    private static function profileSelectList(array $profileConfigList): array
     {
-        if ('openvpn' === $useProto) {
-            return ['wireguard' => false, 'openvpn' => true];
-        }
-        if ('wireguard' === $useProto) {
-            return ['wireguard' => true, 'openvpn' => false];
+        $profileSelectList = [
+            'profileList' => [],
+        ];
+
+        $rowCount = 0;
+        foreach ($profileConfigList as $profileConfig) {
+            $rowCount++;
+            $protoTransportList = [];
+            if ($profileConfig->oSupport()) {
+                if (0 !== count($profileConfig->oUdpPortList())) {
+                    $protoTransportList[] = 'ou';
+                }
+                if (0 !== count($profileConfig->oTcpPortList())) {
+                    $protoTransportList[] = 'ot';
+                }
+            }
+            if ($profileConfig->wSupport()) {
+                $protoTransportList[] = 'wu';
+            }
+            $rowCount += count($protoTransportList);
+            $profileSelectList['profileList'][] = [
+                'profileId' => $profileConfig->profileId(),
+                'displayName' => $profileConfig->displayName(),
+                'protoTransportList' => $protoTransportList,
+            ];
         }
 
-        return ['wireguard' => true, 'openvpn' => true];
+        $profileSelectList['rowCount'] = $rowCount;
+
+        return $profileSelectList;
     }
 }
