@@ -36,7 +36,7 @@ class Ip
 
     public function __toString(): string
     {
-        return $this->address().'/'.$this->ipPrefix;
+        return $this->address() . '/' . $this->ipPrefix;
     }
 
     public static function fromIp(string $ipAddress, ?int $ipPrefix = null): self
@@ -62,8 +62,12 @@ class Ip
         return self::fromIp($ipAddress, (int) $ipPrefix);
     }
 
-    public function address(): string
+    public function address(bool $sixBrackets = false): string
     {
+        if ($sixBrackets && self::IP_6 === $this->ipFamily) {
+            return sprintf('[%s]', self::toAddress($this->ipAddress, $this->addressBits()));
+        }
+
         return self::toAddress($this->ipAddress, $this->addressBits());
     }
 
@@ -146,7 +150,7 @@ class Ip
 
     public function firstHostPrefix(): string
     {
-        return $this->firstHost().'/'.$this->prefix();
+        return $this->firstHost() . '/' . $this->prefix();
     }
 
     /**
@@ -196,7 +200,7 @@ class Ip
         if (self::IP_6 === $this->ipFamily) {
             $minPrefix = 112 - $requiredBits;
             if ($minPrefix < $this->ipPrefix) {
-                throw new IpException('network too small, must be >= /'.$minPrefix);
+                throw new IpException('network too small, must be >= /' . $minPrefix);
             }
         }
         $netIp = $this->network();
