@@ -32,47 +32,74 @@ class LogConnectionHook implements ConnectionHookInterface
     public function connect(string $userId, string $profileId, string $vpnProto, string $connectionId, string $ipFour, string $ipSix, ?string $originatingIp): void
     {
         $this->logger->info(
-            self::logConnect($userId, $profileId, $connectionId, $ipFour, $ipSix, $originatingIp)
+            self::logConnect($userId, $profileId, $vpnProto, $connectionId, $ipFour, $ipSix, $originatingIp)
         );
     }
 
     public function disconnect(string $userId, string $profileId, string $vpnProto, string $connectionId, string $ipFour, string $ipSix, int $bytesIn, int $bytesOut): void
     {
         $this->logger->info(
-            self::logDisconnect($userId, $profileId, $connectionId, $ipFour, $ipSix)
+            self::logDisconnect($userId, $profileId, $vpnProto, $connectionId, $ipFour, $ipSix, $bytesIn, $bytesOut)
         );
     }
 
-    private function logConnect(string $userId, string $profileId, string $connectionId, string $ipFour, string $ipSix, ?string $originatingIp): string
+    private function logConnect(string $userId, string $profileId, string $vpnProto, string $connectionId, string $ipFour, string $ipSix, ?string $originatingIp): string
     {
         if (!$this->logConfig->originatingIp() || null === $originatingIp) {
             $originatingIp = '*';
         }
 
-        $logMsg = sprintf(
-            'CONNECT %s (%s:%s) [%s => %s,%s]',
-            $userId,
-            $profileId,
-            $connectionId,
-            $originatingIp,
-            $ipFour,
-            $ipSix
+        return str_replace(
+            [
+                '{{USER_ID}}',
+                '{{PROFILE_ID}}',
+                '{{VPN_PROTO}}',
+                '{{CONNECTION_ID}}',
+                '{{IP_FOUR}}',
+                '{{IP_SIX}}',
+                '{{ORIGINATING_IP}}',
+                '{{AUTH_DATA}}',
+            ],
+            [
+                $userId,
+                $profileId,
+                $vpnProto,
+                $connectionId,
+                $ipFour,
+                $ipSix,
+                $originatingIp,
+                $this->authData($userId),
+            ],
+            $this->logConfig->connectLogTemplate()
         );
-
-        if ($this->logConfig->authData()) {
-            $logMsg .= sprintf(' [AUTH_DATA=%s]', $this->authData($userId));
-        }
-
-        return $logMsg;
     }
 
-    private function logDisconnect(string $userId, string $profileId, string $connectionId, string $ipFour, string $ipSix): string
+    private function logDisconnect(string $userId, string $profileId, string $vpnProto, string $connectionId, string $ipFour, string $ipSix, int $bytesIn, int $bytesOut): string
     {
-        return sprintf(
-            'DISCONNECT %s (%s:%s)',
-            $userId,
-            $profileId,
-            $connectionId
+        return str_replace(
+            [
+                '{{USER_ID}}',
+                '{{PROFILE_ID}}',
+                '{{VPN_PROTO}}',
+                '{{CONNECTION_ID}}',
+                '{{IP_FOUR}}',
+                '{{IP_SIX}}',
+                '{{BYTES_IN}}',
+                '{{BYTES_OUT}}',
+                '{{AUTH_DATA}}',
+            ],
+            [
+                $userId,
+                $profileId,
+                $vpnProto,
+                $connectionId,
+                $ipFour,
+                $ipSix,
+                (string) $bytesIn,
+                (string) $bytesOut,
+                $this->authData($userId),
+            ],
+            $this->logConfig->disconnectLogTemplate()
         );
     }
 
