@@ -28,7 +28,8 @@ class Storage
         $db = new PDO(
             $dbConfig->dbDsn(),
             $dbConfig->dbUser(),
-            $dbConfig->dbPass()
+            $dbConfig->dbPass(),
+            $dbConfig->dbOptions()
         );
         $db->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
 
@@ -180,7 +181,12 @@ class Storage
         $stmt->bindValue(':node_number', $nodeNumber, PDO::PARAM_INT);
         $stmt->execute();
 
-        return $stmt->fetchAll(PDO::FETCH_COLUMN);
+        $wAllocatedIpFourList = [];
+        foreach ($stmt->fetchAll(PDO::FETCH_ASSOC) as $resultRow) {
+            $wAllocatedIpFourList[] = (string) $resultRow['ip_four'];
+        }
+
+        return $wAllocatedIpFourList;
     }
 
     /**
@@ -220,7 +226,7 @@ class Storage
                 'public_key' => (string) $resultRow['public_key'],
                 'ip_four' => (string) $resultRow['ip_four'],
                 'ip_six' => (string) $resultRow['ip_six'],
-                'expires_at' => Dt::get($resultRow['expires_at']),
+                'expires_at' => Dt::get((string) $resultRow['expires_at']),
                 'auth_key' => null === $resultRow['auth_key'] ? null : (string) $resultRow['auth_key'],
             ];
         }
@@ -281,8 +287,12 @@ class Storage
         );
 
         $stmt->execute();
+        $localUserList = [];
+        foreach ($stmt->fetchAll(PDO::FETCH_ASSOC) as $resultRow) {
+            $localUserList[] = (string) $resultRow['user_id'];
+        }
 
-        return $stmt->fetchAll(PDO::FETCH_COLUMN);
+        return $localUserList;
     }
 
     public function localUserExists(string $authUser): bool
@@ -610,8 +620,8 @@ class Storage
                 'public_key' => $publicKey,
                 'ip_four' => (string) $resultRow['ip_four'],
                 'ip_six' => (string) $resultRow['ip_six'],
-                'created_at' => Dt::get($resultRow['created_at']),
-                'expires_at' => Dt::get($resultRow['expires_at']),
+                'created_at' => Dt::get((string) $resultRow['created_at']),
+                'expires_at' => Dt::get((string) $resultRow['expires_at']),
                 'auth_key' => null === $resultRow['auth_key'] ? null : (string) $resultRow['auth_key'],
                 'user_is_disabled' => (bool) $resultRow['user_is_disabled'],
             ];
@@ -655,8 +665,8 @@ class Storage
                 'profile_id' => (string) $resultRow['profile_id'],
                 'display_name' => (string) $resultRow['display_name'],
                 'common_name' => $commonName,
-                'created_at' => Dt::get($resultRow['created_at']),
-                'expires_at' => Dt::get($resultRow['expires_at']),
+                'created_at' => Dt::get((string) $resultRow['created_at']),
+                'expires_at' => Dt::get((string) $resultRow['expires_at']),
                 'auth_key' => null === $resultRow['auth_key'] ? null : (string) $resultRow['auth_key'],
                 'user_is_disabled' => (bool) $resultRow['user_is_disabled'],
             ];
@@ -697,7 +707,7 @@ class Storage
                 'node_number' => (int) $resultRow['node_number'],
                 'common_name' => (string) $resultRow['common_name'],
                 'display_name' => (string) $resultRow['display_name'],
-                'expires_at' => Dt::get($resultRow['expires_at']),
+                'expires_at' => Dt::get((string) $resultRow['expires_at']),
                 'auth_key' => null === $resultRow['auth_key'] ? null : (string) $resultRow['auth_key'],
             ];
         }
@@ -763,7 +773,7 @@ class Storage
                     UPDATE
                         users
                     SET
-                        is_disabled = 1
+                        is_disabled = true
                     WHERE
                         user_id = :user_id
                 SQL
@@ -779,7 +789,7 @@ class Storage
                     UPDATE
                         users
                     SET
-                        is_disabled = 0
+                        is_disabled = false
                     WHERE
                         user_id = :user_id
                 SQL
@@ -1168,7 +1178,7 @@ class Storage
         $statsData = [];
         foreach ($stmt->fetchAll(PDO::FETCH_ASSOC) as $resultRow) {
             $statsData[] = [
-                'date_time' => Dt::get($resultRow['date_time']),
+                'date_time' => Dt::get((string) $resultRow['date_time']),
                 'connection_count' => (int) $resultRow['connection_count'],
             ];
         }
@@ -1206,7 +1216,7 @@ class Storage
     /**
      * @return array<string,array{unique_user_count:int}>
      *
-     * @deprecated merge with statsYesterdayUniqueGuestUserCount
+     * TODO merge with statsYesterdayUniqueGuestUserCount
      */
     public function statsGetUniqueUsers(DateTimeImmutable $dateTime): array
     {
@@ -1239,7 +1249,7 @@ class Storage
     /**
      * @return array<string,array{unique_user_count:int}>
      *
-     * @deprecated merge with statsYesterdayUniqueUserCount
+     * TODO merge with statsYesterdayUniqueUserCount
      */
     public function statsGetUniqueGuestUsers(DateTimeImmutable $dateTime): array
     {
@@ -1470,8 +1480,15 @@ class Storage
                 SQL
         );
         $stmt->execute();
+        $appUsage = [];
+        foreach ($stmt->fetchAll(PDO::FETCH_ASSOC) as $resultRow) {
+            $appUsage[] = [
+                'client_id' => (string) $resultRow['client_id'],
+                'client_count' => (int) $resultRow['client_count'],
+            ];
+        }
 
-        return $stmt->fetchAll(PDO::FETCH_ASSOC);
+        return $appUsage;
     }
 
     /**
