@@ -16,7 +16,6 @@ use DateTimeZone;
 use fkooman\OAuth\Server\ClientDbInterface;
 use RangeException;
 use Vpn\Portal\Exception\TplException;
-use Vpn\Portal\OAuth\VpnClientDb;
 
 class Tpl implements TplInterface
 {
@@ -49,14 +48,14 @@ class Tpl implements TplInterface
     /**
      * @param array<string,mixed> $templateVariables
      */
-    public function __construct(string $baseDir, ?string $styleName, string $uiLanguage, array $templateVariables = [])
+    public function __construct(string $baseDir, ?string $styleName, string $uiLanguage, array $templateVariables, ClientDbInterface $clientDb)
     {
         $this->templateFolderList = self::templateFolderList($baseDir, $styleName);
         $this->translationFolderList = self::translationFolderList($baseDir, $styleName);
         $this->uiLanguage = $uiLanguage;
-        $this->assetDir = $baseDir.'/web';
+        $this->assetDir = $baseDir . '/web';
         $this->templateVariables = $templateVariables;
-        $this->clientDb = new VpnClientDb($baseDir.'/config/oauth_client_db.json');
+        $this->clientDb = $clientDb;
     }
 
     /**
@@ -189,13 +188,13 @@ class Tpl implements TplInterface
      */
     public function getAssetUrl(string $requestRoot, string $assetPath): string
     {
-        if (false === $mTime = @filemtime($this->assetDir.'/'.$assetPath)) {
+        if (false === $mTime = @filemtime($this->assetDir . '/' . $assetPath)) {
             // can't find file or determine last modified time, do not include
             // cache busting query parameter
-            return $this->e($requestRoot.$assetPath);
+            return $this->e($requestRoot . $assetPath);
         }
 
-        return $this->e($requestRoot.$assetPath.'?mTime='.$mTime);
+        return $this->e($requestRoot . $assetPath . '?mTime=' . $mTime);
     }
 
     public function start(string $sectionName): void
@@ -272,7 +271,7 @@ class Tpl implements TplInterface
         $partOne = substr($inputString, 0, (int) ceil(($maxLen - 1) / 2));
         $partTwo = substr($inputString, (int) -floor(($maxLen - 1) / 2));
 
-        return $this->e($partOne.'…'.$partTwo, $cb);
+        return $this->e($partOne . '…' . $partTwo, $cb);
     }
 
     public function batch(string $v, string $cb): string
@@ -323,7 +322,7 @@ class Tpl implements TplInterface
         $translatedText = $v;
         if ('en-US' !== $this->uiLanguage) {
             foreach ($this->translationFolderList as $translationFolder) {
-                $translationFile = $translationFolder.'/'.$this->uiLanguage.'.php';
+                $translationFile = $translationFolder . '/' . $this->uiLanguage . '.php';
                 if (!file_exists($translationFile)) {
                     continue;
                 }
@@ -344,7 +343,7 @@ class Tpl implements TplInterface
         $escapedVars = [];
         foreach ($this->templateVariables as $k => $v) {
             if (\is_string($v)) {
-                $escapedVars['%'.$k.'%'] = $this->e($v);
+                $escapedVars['%' . $k . '%'] = $this->e($v);
             }
         }
 
@@ -426,12 +425,12 @@ class Tpl implements TplInterface
     private static function templateFolderList(string $baseDir, ?string $styleName): array
     {
         $templateDirs = [
-            $baseDir.'/views',
-            $baseDir.'/config/views',
+            $baseDir . '/views',
+            $baseDir . '/config/views',
         ];
         if (null !== $styleName) {
-            $templateDirs[] = $baseDir.'/views/'.$styleName;
-            $templateDirs[] = $baseDir.'/config/views/'.$styleName;
+            $templateDirs[] = $baseDir . '/views/' . $styleName;
+            $templateDirs[] = $baseDir . '/config/views/' . $styleName;
         }
 
         return $templateDirs;
@@ -443,12 +442,12 @@ class Tpl implements TplInterface
     private static function translationFolderList(string $baseDir, ?string $styleName): array
     {
         $translationDirs = [
-            $baseDir.'/locale',
-            $baseDir.'/config/locale',
+            $baseDir . '/locale',
+            $baseDir . '/config/locale',
         ];
         if (null !== $styleName) {
-            $translationDirs[] = $baseDir.'/locale/'.$styleName;
-            $translationDirs[] = $baseDir.'/config/locale/'.$styleName;
+            $translationDirs[] = $baseDir . '/locale/' . $styleName;
+            $translationDirs[] = $baseDir . '/config/locale/' . $styleName;
         }
 
         return $translationDirs;
