@@ -12,6 +12,7 @@ declare(strict_types=1);
 namespace Vpn\Portal;
 
 use DateTimeImmutable;
+use DomainException;
 use RangeException;
 
 /**
@@ -28,6 +29,40 @@ class Validator
     private const REGEXP_SERVER_NAME = '/^[a-zA-Z0-9-.]+$/';
     private const REGEXP_VPN_USER_GROUP = '/^[_a-zA-Z0-9]+$/';
 
+    /**
+     * @throws \RangeException
+     */
+    public static function profileProtoTransport(string $profileProtoTransport): void
+    {
+        self::parseProfileProtoTransport($profileProtoTransport);
+    }
+
+    /**
+     * We validate the "profileProtoTransport" here, it is of the form:
+     * ${PROFILE_ID}_${PROTO}${TRANSPORT}
+     *
+     * Examples:
+     * - default_ou (OpenVPN, Prefer UDP)
+     * - default_ot (OpenVPN, Prefer TCP)
+     * - default_wu (WireGuard, Prefer UDP)
+     *
+     * @throws \RangeException
+     *
+     * @return array{string,string}
+     */
+    public static function parseProfileProtoTransport(string $profileProtoTransport): array
+    {
+        $e = explode('_', $profileProtoTransport, 2);
+        if (2 !== count($e)) {
+            throw new RangeException();
+        }
+        [$profileId, $protoTransport] = $e;
+        self::re($profileId, self::REGEXP_PROFILE_ID);
+        self::inSet($protoTransport, ['ou', 'ot', 'wu']);
+
+        return $e;
+    }
+
     /**
      * @throws \RangeException
      */
@@ -170,11 +205,6 @@ class Validator
         self::inSet($yesOrNo, ['yes', 'no']);
     }
 
-    public static function vpnProto(string $vpnProto): void
-    {
-        self::inSet($vpnProto, ['openvpn', 'wireguard', 'default']);
-    }
-
     public static function vpnUser(string $vpnUser): void
     {
         self::re($vpnUser, self::REGEXP_VPN_USER_GROUP);
@@ -235,9 +265,9 @@ class Validator
             // not a valid host
             throw new RangeException();
         }
-        $constructedUrl = $urlScheme.'://'.$urlHost;
+        $constructedUrl = $urlScheme . '://' . $urlHost;
         if (null !== $urlPort = parse_url($urlToMatch, PHP_URL_PORT)) {
-            $constructedUrl .= ':'.(string) $urlPort;
+            $constructedUrl .= ':' . (string) $urlPort;
         }
 
         if ($httpOrigin !== $constructedUrl) {
@@ -280,6 +310,9 @@ class Validator
      */
     private static function re(string $inputStr, string $regExp): void
     {
+        if ('' === $regExp) {
+            throw new DomainException('regexp can not be empty');
+        }
         if (1 !== preg_match($regExp, $inputStr)) {
             throw new RangeException();
         }
