@@ -9,9 +9,10 @@ declare(strict_types=1);
  * SPDX-License-Identifier: AGPL-3.0+
  */
 
-require_once dirname(__DIR__).'/vendor/autoload.php';
+require_once dirname(__DIR__) . '/vendor/autoload.php';
 $baseDir = dirname(__DIR__);
 
+use fkooman\OAuth\Server\PdoStorage as OAuthStorage;
 use fkooman\OAuth\Server\Signer;
 use Vpn\Portal\Cfg\Config;
 use Vpn\Portal\ConnectionHooks;
@@ -45,11 +46,12 @@ try {
 
     $dateTime = Dt::get();
     $request = Request::createFromGlobals();
-    FileIO::mkdir($baseDir.'/data');
-    $config = Config::fromFile($baseDir.'/config/config.php');
+    FileIO::mkdir($baseDir . '/data');
+    $config = Config::fromFile($baseDir . '/config/config.php');
     $storage = new Storage($config->dbConfig($baseDir));
-    $ca = new VpnCa($baseDir.'/config/keys/ca', $config->vpnCaPath());
-    $oauthKey = FileIO::read($baseDir.'/config/keys/oauth.key');
+    $oauthStorage = new OAuthStorage($storage->dbPdo(), 'oauth_');
+    $ca = new VpnCa($baseDir . '/config/keys/ca', $config->vpnCaPath());
+    $oauthKey = FileIO::read($baseDir . '/config/keys/oauth.key');
     $service = new AdminApiService(
         new AdminApiAuthModule(
             $adminApiKeyFile,
@@ -58,14 +60,14 @@ try {
     );
     $serverInfo = new ServerInfo(
         $request->getRootUri(),
-        $baseDir.'/data/keys',
+        $baseDir . '/data/keys',
         $ca,
-        new TlsCrypt($baseDir.'/data/keys'),
+        new TlsCrypt($baseDir . '/data/keys'),
         $config->wireGuardConfig(),
         Signer::publicKeyFromSecretKey($oauthKey)
     );
 
-    $connectionManager = new ConnectionManager($config, new VpnDaemon(new CurlHttpClient($baseDir.'/config/keys/vpn-daemon'), $logger), $storage, ConnectionHooks::init($config, $storage, $logger), $logger);
+    $connectionManager = new ConnectionManager($config, new VpnDaemon(new CurlHttpClient($baseDir . '/config/keys/vpn-daemon'), $logger), $storage, ConnectionHooks::init($config, $storage, $logger), $logger);
 
     $sessionExpiry = new Expiry(
         $config->sessionExpiry(),
@@ -78,6 +80,7 @@ try {
         new AdminApiModule(
             $config,
             $storage,
+            $oauthStorage,
             $serverInfo,
             $connectionManager,
             $sessionExpiry
