@@ -9,7 +9,7 @@ declare(strict_types=1);
  * SPDX-License-Identifier: AGPL-3.0+
  */
 
-require_once dirname(__DIR__).'/vendor/autoload.php';
+require_once dirname(__DIR__) . '/vendor/autoload.php';
 $baseDir = dirname(__DIR__);
 
 use fkooman\OAuth\Server\PdoStorage as OAuthStorage;
@@ -53,8 +53,9 @@ use Vpn\Portal\OAuth\VpnClientDb;
 use Vpn\Portal\OAuth\VpnOAuthServer;
 use Vpn\Portal\OpenVpn\CA\VpnCa;
 use Vpn\Portal\OpenVpn\TlsCrypt;
+use Vpn\Portal\PermissionSourceManager;
 use Vpn\Portal\ServerInfo;
-use Vpn\Portal\StaticPermissionSource;
+use Vpn\Portal\StaticPermissionsSource;
 use Vpn\Portal\Storage;
 use Vpn\Portal\SysLogger;
 use Vpn\Portal\Tpl;
@@ -67,13 +68,14 @@ umask(0077);
 $logger = new SysLogger('vpn-user-portal');
 
 try {
-    $config = Config::fromFile($baseDir.'/config/config.php');
+    $config = Config::fromFile($baseDir . '/config/config.php');
     $request = Request::createFromGlobals();
 
-    // determine perferred UI language
-    if (null === $uiLanguage = $request->getCookie('L', fn (string $s) => Validator::languageCode($s))) {
+    // determine preferred UI language
+    if (null === $uiLanguage = $request->getCookie('L', fn(string $s) => Validator::languageCode($s))) {
         $uiLanguage = $config->defaultLanguage();
     }
+    $oauthClientDb = new VpnClientDb($baseDir . '/config/oauth_client_db.json', $config->apiConfig()->appSets());
     $tpl = new Tpl(
         $baseDir,
         $config->styleName(),
@@ -81,17 +83,18 @@ try {
         [
             'requestRoot' => $request->getRoot(),
             'portalHost' => gethostname(),
-            'portalVersion' => trim(FileIO::read($baseDir.'/VERSION')),
+            'portalVersion' => trim(FileIO::read($baseDir . '/VERSION')),
             'enabledLanguages' => $config->enabledLanguages(),
             'authModule' => $config->authModule(),
             'isAdmin' => false,
             'showLogoutButton' => true,
-        ]
+        ],
+        $oauthClientDb
     );
 
     $dateTime = Dt::get();
-    FileIO::mkdir($baseDir.'/data');
-    $ca = new VpnCa($baseDir.'/config/keys/ca', $config->vpnCaPath());
+    FileIO::mkdir($baseDir . '/data');
+    $ca = new VpnCa($baseDir . '/config/keys/ca', $config->vpnCaPath());
     $sessionExpiry = new Expiry(
         $config->sessionExpiry(),
         $config->supportedSessionExpiry(),
@@ -106,6 +109,7 @@ try {
     $cookieBackend = new SeCookie(new Cookie($cookieOptions->withMaxAge(60 * 60 * 24 * 90)->withSameSiteLax()));
     $sessionBackend = new SeSession($cookieOptions->withSameSiteStrict(), $config);
 
+    $ldapCredentialValidator = null;
     switch ($config->authModule()) {
         case 'DbAuthModule':
             $dbCredentialStorage = new DbCredentialValidator($storage);
@@ -119,11 +123,9 @@ try {
             break;
 
         case 'LdapAuthModule':
+            $ldapCredentialValidator = new LdapCredentialValidator($config->ldapAuthConfig());
             $authModule = new UserPassAuthModule(
-                new LdapCredentialValidator(
-                    $config->ldapAuthConfig(),
-                    $logger
-                ),
+                $ldapCredentialValidator,
                 $sessionBackend,
                 $tpl,
                 $logger
@@ -170,7 +172,7 @@ try {
 
     $service = new PortalService($authModule, $tpl);
     if ($config->apiConfig()->enableGuestAccess()) {
-        $service->addHook(new HmacUserIdHook(HmacKey::load(FileIO::read($baseDir.'/config/keys/hmac.key'))));
+        $service->addHook(new HmacUserIdHook(HmacKey::load(FileIO::read($baseDir . '/config/keys/hmac.key'))));
     }
     $service->addHook(new CsrfProtectionHook());
 
@@ -188,10 +190,8 @@ try {
         $service->addHook(new AccessHook($accessPermissionList));
     }
 
-    $permissionSourceList = [
-        new StaticPermissionSource($baseDir.'/config/static_permissions.json'),
-    ];
-    $service->addHook(new UpdateUserInfoHook($sessionBackend, $storage, $authModule, $permissionSourceList));
+    $staticPermissionsSource = new StaticPermissionsSource($config->staticPermissionsConfig($baseDir), $request);
+    $service->addHook(new UpdateUserInfoHook($sessionBackend, $storage, $authModule, $staticPermissionsSource));
     $service->addHook(new DisabledUserHook());
 
     // isAdmin
@@ -202,22 +202,29 @@ try {
     );
 
     $service->addHook($adminHook);
-    $oauthClientDb = new VpnClientDb($baseDir.'/config/oauth_client_db.json');
     $oauthStorage = new OAuthStorage($storage->dbPdo(), 'oauth_');
-    $oauthKey = FileIO::read($baseDir.'/config/keys/oauth.key');
+    $oauthKey = FileIO::read($baseDir . '/config/keys/oauth.key');
     $oauthSigner = new Signer($oauthKey);
     $serverInfo = new ServerInfo(
         $request->getRootUri(),
-        $baseDir.'/data/keys',
+        $baseDir . '/data/keys',
         $ca,
-        new TlsCrypt($baseDir.'/data/keys'),
+        new TlsCrypt($baseDir . '/data/keys'),
         $config->wireGuardConfig(),
         Signer::publicKeyFromSecretKey($oauthKey)
     );
 
-    $vpnDaemon = new VpnDaemon(new CurlHttpClient($baseDir.'/config/keys/vpn-daemon'), $logger);
+    $vpnDaemon = new VpnDaemon(new CurlHttpClient($baseDir . '/config/keys/vpn-daemon'), $logger);
     $connectionManager = new ConnectionManager($config, $vpnDaemon, $storage, ConnectionHooks::init($config, $storage, $logger), $logger);
 
+    $permissionSourceManager = new PermissionSourceManager();
+    if ($config->staticPermissionsConfig($baseDir)->isLivePermissionSource()) {
+        $permissionSourceManager->add($staticPermissionsSource);
+    }
+    if ($config->ldapAuthConfig()->isLivePermissionSource()) {
+        $permissionSourceManager->add($ldapCredentialValidator ?? new LdapCredentialValidator($config->ldapAuthConfig()));
+    }
+
     // portal module
     $vpnPortalModule = new VpnPortalModule(
         $config,
@@ -227,7 +234,8 @@ try {
         $storage,
         $oauthStorage,
         $serverInfo,
-        $sessionExpiry
+        $sessionExpiry,
+        $permissionSourceManager
     );
     $service->addModule($vpnPortalModule);
 
@@ -248,7 +256,7 @@ try {
         $oauthSigner,
         $config->apiConfig()->tokenExpiry()
     );
-    $oauthServer->setIssuerIdentity($request->getOrigin().'/');
+    $oauthServer->setIssuerIdentity($request->getOrigin() . '/');
 
     $oauthModule = new OAuthModule(
         $oauthServer,
