@@ -9,7 +9,7 @@ declare(strict_types=1);
  * SPDX-License-Identifier: AGPL-3.0+
  */
 
-require_once dirname(__DIR__).'/vendor/autoload.php';
+require_once dirname(__DIR__) . '/vendor/autoload.php';
 $baseDir = dirname(__DIR__);
 
 use fkooman\OAuth\Server\PdoStorage as OAuthStorage;
@@ -22,7 +22,6 @@ use Vpn\Portal\Http\OAuthTokenService;
 use Vpn\Portal\Http\Request;
 use Vpn\Portal\OAuth\VpnClientDb;
 use Vpn\Portal\OAuth\VpnOAuthServer;
-use Vpn\Portal\OpenVpn\CA\VpnCa;
 use Vpn\Portal\Storage;
 use Vpn\Portal\SysLogger;
 
@@ -33,7 +32,7 @@ $logger = new SysLogger('vpn-user-portal');
 
 try {
     $request = Request::createFromGlobals();
-    FileIO::mkdir($baseDir.'/data');
+    FileIO::mkdir($baseDir . '/data');
 
     // workaround for macOS/iOS client on server upgrade trying to use the old
     // 2.x OAuth token endpoint on 3.x server
@@ -55,19 +54,18 @@ try {
         exit(0);
     }
 
-    $config = Config::fromFile($baseDir.'/config/config.php');
+    $config = Config::fromFile($baseDir . '/config/config.php');
     $service = new OAuthTokenService();
     $storage = new Storage($config->dbConfig($baseDir));
-    $ca = new VpnCa($baseDir.'/config/keys/ca', $config->vpnCaPath());
 
     // OAuth module
     $oauthServer = new VpnOAuthServer(
         new OAuthStorage($storage->dbPdo(), 'oauth_'),
-        new VpnClientDb($baseDir.'/config/oauth_client_db.json'),
-        new Signer(FileIO::read($baseDir.'/config/keys/oauth.key')),
+        new VpnClientDb($baseDir . '/config/oauth_client_db.json', $config->apiConfig()->appSets()),
+        new Signer(FileIO::read($baseDir . '/config/keys/oauth.key')),
         $config->apiConfig()->tokenExpiry()
     );
-    $oauthServer->setIssuerIdentity($request->getOrigin().'/');
+    $oauthServer->setIssuerIdentity($request->getOrigin() . '/');
 
     $oauthModule = new OAuthTokenModule(
         $oauthServer
